@@ -88,12 +88,7 @@ void recursiveExploration1DBound(Eigen::ArrayXc &p_levelCurrent,
     if (p_iterLevel == p_dataSet.end())
         return ;
     // achieve 1D Heriarchization for the current node and given direction
-
-#ifdef _MSC_VER  // VS Bug ?
-    HierDehier().operator()<T, TT>(p_levelCurrent, p_positionCurrent, p_iterLevel,  p_idim, p_dataSet, p_source, p_output);
-#else
     HierDehier().template operator()<T, TT>(p_levelCurrent, p_positionCurrent, p_iterLevel,  p_idim, p_dataSet, p_source, p_output);
-#endif
 
     // recursive
     for (size_t idd = 0 ; idd < p_idimRemain; ++idd)
