@@ -135,7 +135,11 @@ void SimulateStepRegressionControlDist::oneStep(vector<StateWithStocks > &p_stat
     boost::mpi::all_gatherv<int>(m_world, simCurrentProc.data(), simCurrentProc.size(), simAllProc);
     // update results
     int iis = 0;
-    for (size_t is = 0; is < simAllProc.size(); ++is)
+    int is = 0;
+#ifdef _OPENMP
+    #pragma omp parallel for  private(is)
+#endif
+    for (is = 0; is < static_cast<int>(simAllProc.size()); ++is)
     {
         for (int iid = 0; iid < m_pOptimize->getSimuFuncSize(); ++iid)
             p_phiInOut(iid, simAllProc[is]) = valueFunctionAllSim[iis++];
