@@ -5,6 +5,9 @@
 #define TRANSITIONSTEPREGRESSIONBASE_H
 #include <vector>
 #include <memory>
+#ifdef USE_MPI
+#include "boost/mpi.hpp"
+#endif
 #include <Eigen/Dense>
 #include "geners/BinaryFileArchive.hh"
 #include "StOpt/regression/BaseRegression.h"
