@@ -61,6 +61,18 @@ public:
         return ret;
     }
 
+    std::vector< std::string> getAllNamesForGridAndRegressedValue()
+    {
+        std::set<std::string> set;
+        auto reference = gs::Reference<std::vector<StOpt::GridAndRegressedValue>>(*this, std::regex(".*"), std::regex(".*"));
+        for (int i = 0; i < reference.size(); ++i)
+        {
+            set.emplace(reference.indexedCatalogEntry(i)->name());
+        }
+        std::vector<std::string> ret(set.begin(), set.end());
+        return ret;
+    }
+
     // to get distinct Names in archive used for Continuation values (cuts)
     std::vector< std::string> getNamesForContinuationCut(const std::string &p_nameRegex)
     {
@@ -74,7 +86,20 @@ public:
         return ret;
     }
 
-    void dumpGridAndRegressedValue(const std::string &p_name, const int &p_iStep, const  pybind11::list  &p_phiIn,
+   std::vector< std::string> getAllNamesForContinuationCut()
+    {
+        std::set<std::string> set;
+        auto reference = gs::Reference<std::vector<StOpt::ContinuationCuts>>(*this, std::regex(".*"), std::regex(".*"));
+        for (int i = 0; i < reference.size(); ++i)
+        {
+            set.emplace(reference.indexedCatalogEntry(i)->name());
+        }
+        std::vector<std::string> ret(set.begin(), set.end());
+        return ret;
+    }
+
+
+  void dumpGridAndRegressedValue(const std::string &p_name, const int &p_iStep, const  pybind11::list  &p_phiIn,
                                    const   std::shared_ptr<StOpt::BaseRegression>    &p_condExp,
                                    const std::shared_ptr< StOpt::SpaceGrid >   &p_grid)
     {
