@@ -63,6 +63,7 @@ namespace py = pybind11;
 
 //Wrapper for simulator of regression
 //***********************************
+#pragma GCC visibility push(hidden)
 
 class PySimulatorDPBase : public StOpt::SimulatorDPBase
 {
@@ -929,6 +930,7 @@ Eigen::ArrayXd  pyReconstructProc0ForIntMpi(const Eigen::ArrayXi &p_point, const
 
 #endif
 
+#pragma GCC visibility pop
 
 
 namespace py = pybind11;
