@@ -339,7 +339,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
         // simulator
         BlackScholesSimulator simulator(initialValues, sigma, mu, corr, dates(dates.size() - 1), dates.size() - 1, nbSimul, false);
         // using continuation values
-        valueSeqContinuation = resolutionSwingContinuationLocalRegression(simulator, payoff, nbMesh, dates, N, "ToDump");
+        valueSeqContinuation = resolutionSwingContinuationLocalRegression(simulator, payoff, nbMesh, dates, N, "ToDumpSwing");
         BOOST_CHECK_EQUAL(valueSeq, valueSeqContinuation);
     }
     // simulator
