@@ -480,12 +480,3 @@ BOOST_AUTO_TEST_CASE(testContinuationLaplacianConstKernel3D)
     TestContinuationValue(500, h, 1e-9, 0.0001);
 }
 
-BOOST_AUTO_TEST_CASE(testContinuationLaplacianConstKernel4D)
-{
-#if defined   __linux
-    enable_abort_on_floating_point_exception();
-#endif
-
-    ArrayXd h = ArrayXd::Constant(4, 0.1) ; // bandwidth
-    TestContinuationValue(10000, h, 1e-9, 0.0001);
-}
