@@ -333,11 +333,11 @@ void  TestSparseRegressionSerialization(const int &p_nDim, const int &p_nbSimul,
         }
 
         // archive
-        BinaryFileArchive ar("archive", "w");
+        BinaryFileArchive ar("archiveSR", "w");
         ar << Record(*sparseRegressor, "Regressor", "Top") ;
     }
     {
-        BinaryFileArchive ar("archive", "r");
+        BinaryFileArchive ar("archiveSR", "r");
         SparseRegression reg;
         Reference< SparseRegression> (ar, "Regressor", "Top").restore(0, &reg);
         for (int is = 0; is < x.size(); ++is)
@@ -413,12 +413,12 @@ void TestContinuationValue(const int &p_nDim, const int &p_nbSimul, const int &p
             BOOST_CHECK_CLOSE(regressedByContinuation(is), regressedValues(sizeForStock / 2, is), accuracyEqual);
 
         // default non compression
-        BinaryFileArchive ar("archive", "w");
+        BinaryFileArchive ar("archiveSR1", "w");
         ar << Record(continuation, "FirstContinuation", "Top") ;
     }
     {
         // read archive
-        BinaryFileArchive ar("archive", "r");
+        BinaryFileArchive ar("archiveSR1", "r");
         ContinuationValue contRead;
         Reference< ContinuationValue >(ar, "FirstContinuation", "Top").restore(0, &contRead);
         ArrayXd ptStock(1) ;
