@@ -54,8 +54,7 @@ class MeanRevertingSimulator :
         if self.m_bForward :
             self.m_OUProcess = np.zeros((len(p_sigma), p_nbSimul))
         else :
-            #for i in list(range(self.m_OUProcess.shape[0])) :
-            stDev = self.m_sigma * math.sqrt((1 - math.exp(-2 * self.m_mr * self.m_T)) / (2 * self.m_mr))
+            stDev = self.m_sigma * np.sqrt((1 - np.exp(-2 * self.m_mr * self.m_T)) / (2 * self.m_mr))
             self.m_OUProcess = stDev * np.random.randn(len(p_sigma), p_nbSimul)
             
         self.actualizeTrend()
